@@ -4,8 +4,7 @@ from dotenv import load_dotenv
 
 if __name__ == "__main__":
     load_dotenv()
-    messenger = WhatsApp(token=getenv("TOKEN"),
-                         phone_number_id={1:"1234", 2: "5678"})
+    messenger = WhatsApp(token=getenv("TOKEN"), phone_number_id={1: "1234", 2: "5678"})
 
     response = messenger.send_button(
         recipient_id="255757xxxxxx",
@@ -30,5 +29,5 @@ if __name__ == "__main__":
                 ],
             },
         },
-        sender=1
+        sender=1,
     )
