@@ -4,8 +4,7 @@ from dotenv import load_dotenv
 
 if __name__ == "__main__":
     load_dotenv()
-    messenger = WhatsApp(token=getenv("TOKEN"),
-                         phone_number_id={1:"1234", 2: "5678"})
+    messenger = WhatsApp(token=getenv("TOKEN"), phone_number_id={1: "1234", 2: "5678"})
 
     response = messenger.send_location(
         lat=1.29,
@@ -13,7 +12,7 @@ if __name__ == "__main__":
         name="Singapore",
         address="Singapore",
         recipient_id="255757294146",
-        sender=1
+        sender=1,
     )
 
     print(response)
