@@ -1,6 +1,7 @@
 import logging
 import requests
 from typing import Dict, Any
+from ..errors import Handle
 
 
 def create_button(self, button: Dict[Any, Any]) -> Dict[Any, Any]:
@@ -24,7 +25,9 @@ def create_button(self, button: Dict[Any, Any]) -> Dict[Any, Any]:
     return data
 
 
-def send_button(self, button: Dict[Any, Any], recipient_id: str, sender=None) -> Dict[Any, Any]:
+def send_button(
+    self, button: Dict[Any, Any], recipient_id: str, sender=None
+) -> Dict[Any, Any]:
     """
     Sends an interactive buttons message to a WhatsApp user
 
@@ -58,7 +61,7 @@ def send_button(self, button: Dict[Any, Any], recipient_id: str, sender=None) ->
     logging.info(f"Buttons not sent to {recipient_id}")
     logging.info(f"Status code: {r.status_code}")
     logging.info(f"Response: {r.json()}")
-    return r.json()
+    return Handle(r.json())
 
 
 def send_reply_button(
@@ -101,4 +104,4 @@ def send_reply_button(
     logging.info(f"Reply buttons not sent to {recipient_id}")
     logging.info(f"Status code: {r.status_code}")
     logging.info(f"Response: {r.json()}")
-    return r.json()
+    return Handle(r.json())
